# Loren Williams, Georgia Tech
# pymol script for tRNA
#-----------------------------------------------------------------------------
## Header: General Commands ##
# delete all objects and reset pymol
reinitialize
# set the background color to white
bg_color white
# make the background transparent for ray trace 
set ray_opaque_background, 0
# set the ray trace mode
# normal color
set ray_trace_mode, 0
# normal color + black outline
#set ray_trace_mode,  1
# black outline only
#set ray_trace_mode,  2
# turn off shadows during ray trace
set ray_shadows, 0
# set the mouse mode for laptop.
config_mouse one_button
# get rid of double bonds and skinny bonds to H
set stick_h_scale, 1
set valence, 0
# high quality surfaces
set surface_quality, 3

## End of Header: General Commands ##
#----------------------------------------
#
load files/577a.pdb
create RNA_stick, 577a
#
#remove res 583

#-----------create an object with only the RNA
create RNA_1, (chain 0)
color green, name C*

#-----------create a second object with only the RNA
create RNA_2, (chain 0)
#
#----------RNA_1----set the representation of the RNA object
#
hide everything, RNA_1
show cartoon, RNA_1
set cartoon_ring_mode=3, RNA_1
set cartoon_tube_radius=0.2, RNA_1

#-------------------------------------G (J-1)
color cyan, res 577 and (RNA_1)

#-------------------------------------N (J)
color lightblue, res 578 and (RNA_1)

#-------------------------------------R (J+1)
color salmon, res 579 and (RNA_1)

#-------------------------------------A (J+2)
color forest, res 580 and (RNA_1)

#-------------------------------------G (J+3)
color orange, res 581 and (RNA_1)

#-------------------------------------STEM
color wheat, res 576 or res 575 or res 574 or res 582 or res 583

#-------------------------------------backbone
color gray70, (RNA_1 and name P)
color gray70, (RNA_1 and name O5')
color gray70, (RNA_1 and name O3*)
#color gray70, (RNA_1 and name P)

#----------RNA_2----show the hydrogen bonding atoms
hide everything, RNA_2

# J-1
show stick, RNA_2 and res 577 and (name C2' or name O2' or name N2 or name C2 or name N1 or name C6)
show sphere, RNA_2 and res 577 and (name O2' or name N2 or name N1)
color cyan, RNA_2 and res 577

# J+1
show stick, RNA_2 and res 579 and (name C8 or name N7 or name C5)
show sphere, RNA_2 and res 579 and (name N7)
color salmon, RNA_2 and res 579

#J+2
show stick, RNA_2 and res 580 and (name O2P or name P or name C8 or name N7 or name C5)
show sphere, RNA_2 and res 580 and (name O2P or name N7)
color forest, RNA_2 and res 580

alter RNA_2, vdw=.4
rebuild

# ----------------------H-bonding ATOM COLORS
color red, RNA_2 and name O2' or name O2P
color blue, RNA_2 and (name N1 or name N2 or name N7)


#-----------hydrogen bonds

distance hbond_loop, /RNA_2//0/G`577/O2' or /RNA_2//0/G`577/N1 or /RNA_2//0/G`577/N2, /RNA_2//0/G`579/N7 or /RNA_2//0/A`580/O2P or /RNA_2//0/A`580/N7, 3.5
#distance hbond1, /RNA_2//0/G`577/O2', /RNA_2//0/G`579/N7, 3.4
#distance hbond2, /RNA_2//0/G`577/N1, /RNA_2//0/A`580/O2P, 3.4
#distance hbond3, /RNA_2//0/G`577/N2, /RNA_2//0/A`580/O2P, 3.4
#distance hbond4, /RNA_2//0/G`577/N2, /RNA_2//0/A`580/N7, 3.5
color black, hbond_loop
hide labels, hbond_loop

distance WC_hbond1, /RNA_stick//0/C`576 or /RNA_stick//0/G`575, /RNA_stick//0/G`581 or /RNA_stick//0/C`582, 3.4
#distance WC_hbond2, /RNA_stick//0/G`575, /RNA_stick//0/C`582, 3.4
distance WC_hbond2, /RNA_stick//0/C`574, /RNA_stick//0/G`583, 2.9



#distance WC_hbond1, /RNA_stick//0/C`576, /RNA_stick//0/G`581, 3.4
#distance WC_hbond2, /RNA_stick//0/G`575, /RNA_stick//0/C`582, 3.4
#distance WC_hbond3, /RNA_stick//0/C`574, /RNA_stick//0/G`583, 2.9

color black, WC_hbond*
hide labels, WC_hbond*
set dash_width, 3
set dash_gap, 0.45

#-----------torsion angles


hide everything, rna_stick
show sticks, rna_stick

dihedral alpha,  (name O3' and resi 575 and rna_stick), (name P and resi 576 and rna_stick), (name O5' and resi 576 and rna_stick), (name C5' and resi 576 and rna_stick) 
dihedral alpha,  (name O3' and resi 576 and rna_stick), (name P and resi 577 and rna_stick), (name O5' and resi 577 and rna_stick), (name C5' and resi 577 and rna_stick) 
dihedral alpha,  (name O3' and resi 577 and rna_stick), (name P and resi 578 and rna_stick), (name O5' and resi 578 and rna_stick), (name C5' and resi 578 and rna_stick) 
dihedral alpha,  (name O3' and resi 578 and rna_stick), (name P and resi 579 and rna_stick), (name O5' and resi 579 and rna_stick), (name C5' and resi 579 and rna_stick) 
dihedral alpha,  (name O3' and resi 579 and rna_stick), (name P and resi 580 and rna_stick), (name O5' and resi 580 and rna_stick), (name C5' and resi 580 and rna_stick) 
dihedral alpha,  (name O3' and resi 580 and rna_stick), (name P and resi 581 and rna_stick), (name O5' and resi 581 and rna_stick), (name C5' and resi 581 and rna_stick) 
dihedral alpha,  (name O3' and resi 581 and rna_stick), (name P and resi 582 and rna_stick), (name O5' and resi 582 and rna_stick), (name C5' and resi 582 and rna_stick) 
color black, alpha
set label_color, black, alpha
set dihedral_size, 1.6, alpha

dihedral beta, (name P and resi 576 and rna_stick), (name O5' and resi 576 and rna_stick),  (name C5' and resi 576 and rna_stick), (name C4' and resi 576 and rna_stick) 
dihedral beta, (name P and resi 577 and rna_stick), (name O5' and resi 577 and rna_stick),  (name C5' and resi 577 and rna_stick), (name C4' and resi 577 and rna_stick) 
dihedral beta, (name P and resi 578 and rna_stick), (name O5' and resi 578 and rna_stick),  (name C5' and resi 578 and rna_stick), (name C4' and resi 578 and rna_stick) 
dihedral beta, (name P and resi 579 and rna_stick), (name O5' and resi 579 and rna_stick),  (name C5' and resi 579 and rna_stick), (name C4' and resi 579 and rna_stick) 
dihedral beta, (name P and resi 580 and rna_stick), (name O5' and resi 580 and rna_stick),  (name C5' and resi 580 and rna_stick), (name C4' and resi 580 and rna_stick) 
dihedral beta, (name P and resi 581 and rna_stick), (name O5' and resi 581 and rna_stick),  (name C5' and resi 581 and rna_stick), (name C4' and resi 581 and rna_stick) 
dihedral beta, (name P and resi 582 and rna_stick), (name O5' and resi 582 and rna_stick),  (name C5' and resi 582 and rna_stick), (name C4' and resi 582 and rna_stick) 
color deepteal, beta
set label_color, deepteal, beta
set dihedral_size, 1.0, beta


dihedral gamma, (name O5' and resi 576 and rna_stick),  (name C5' and resi 576 and rna_stick), (name C4' and resi 576 and rna_stick), (name C3' and resi 576 and rna_stick) 
dihedral gamma, (name O5' and resi 577 and rna_stick),  (name C5' and resi 577 and rna_stick), (name C4' and resi 577 and rna_stick), (name C3' and resi 577 and rna_stick) 
dihedral gamma, (name O5' and resi 578 and rna_stick),  (name C5' and resi 578 and rna_stick), (name C4' and resi 578 and rna_stick), (name C3' and resi 578 and rna_stick)
dihedral gamma, (name O5' and resi 579 and rna_stick),  (name C5' and resi 579 and rna_stick), (name C4' and resi 579 and rna_stick), (name C3' and resi 579 and rna_stick)  
dihedral gamma, (name O5' and resi 580 and rna_stick),  (name C5' and resi 580 and rna_stick), (name C4' and resi 580 and rna_stick), (name C3' and resi 580 and rna_stick)  
dihedral gamma, (name O5' and resi 581 and rna_stick),  (name C5' and resi 581 and rna_stick), (name C4' and resi 581 and rna_stick), (name C3' and resi 581 and rna_stick)  
dihedral gamma, (name O5' and resi 582 and rna_stick),  (name C5' and resi 582 and rna_stick), (name C4' and resi 582 and rna_stick), (name C3' and resi 582 and rna_stick)  
color red, gamma
set label_color, red, gamma
set dihedral_size, 1.6, gamma



dihedral delta, (name C5' and resi 576 and rna_stick),  (name C4' and resi 576 and rna_stick), (name C3' and resi 576 and rna_stick), (name O3' and resi 576 and rna_stick) 
dihedral delta, (name C5' and resi 577 and rna_stick), (name C4' and resi 577 and rna_stick), (name C3' and resi 577 and rna_stick), (name O3' and resi 577 and rna_stick)  
dihedral delta, (name C5' and resi 578 and rna_stick), (name C4' and resi 578 and rna_stick), (name C3' and resi 578 and rna_stick), (name O3' and resi 578 and rna_stick) 
dihedral delta, (name C5' and resi 579 and rna_stick), (name C4' and resi 579 and rna_stick), (name C3' and resi 579 and rna_stick), (name O3' and resi 579 and rna_stick)   
dihedral delta, (name C5' and resi 580 and rna_stick), (name C4' and resi 580 and rna_stick), (name C3' and resi 580 and rna_stick), (name O3' and resi 580 and rna_stick)   
dihedral delta, (name C5' and resi 581 and rna_stick), (name C4' and resi 581 and rna_stick), (name C3' and resi 581 and rna_stick), (name O3' and resi 581 and rna_stick)   
dihedral delta, (name C5' and resi 582 and rna_stick), (name C4' and resi 582 and rna_stick), (name C3' and resi 582 and rna_stick), (name O3' and resi 582 and rna_stick)   
color blue, delta
set label_color, blue, delta
set dihedral_size, 1.2, delta


dihedral epsilon, (name C4' and resi 576 and rna_stick), (name C3' and resi 576 and rna_stick), (name O3' and resi 576 and rna_stick), (name P and resi 577 and rna_stick)   
color magenta, epsilon
set label_color, magenta, epsilon
set dihedral_size, 1.6, epsilon

dihedral zeta, (name C3' and resi 576 and rna_stick), (name O3' and resi 576 and rna_stick), (name P and resi 577 and rna_stick), (name O5' and resi 577 and rna_stick)   
color orange, zeta
set label_color, orange, zeta
set dihedral_size, 1.2, zeta


set line_width, 7




######-----------------------------load the deleted tetraloop
load  files/d2_tl.pdb, d2_tl
remove resi 1813-1815 and d2_tl
remove name XD and d2_tl
show stick, d2_tl 

######-----------------------------

######-----------------------------load the inserted tetraloop
load  files/i2_tl.pdb, i2_tl
remove resi 1813-1815 and d2_tl
remove name XD and i2_tl
remove resi 1714 and i2_tl


hide everything, i2_tl
show cartoon, i2_tl
set cartoon_ring_mode=3, i2_tl
set cartoon_tube_radius=0.2, i2_tl
show stick, i2_tl 
color wheat, atom C and i2_tl



######-----------------------------
create RNA, RNA_stick
label RNA and resi 576 and name N1, "C"
label RNA and resi 577 and name C8, "G"
label RNA and resi 578 and name N1, "N (any base)"
label RNA and resi 579 and name C1', "R (purine)"
label RNA and resi 580 and name C8, "A"
label RNA and resi 581 and name N9, "G"

set label_position,(-3,-1.5,0)
set label_size, 20

delete 577a
delete RNA_stick
delete RNA_2

disable All
enable hbond*
enable wc_hbond*
enable RNA


set_view (\
     0.446927726,    0.401872993,    0.799228907,\
     0.872891486,   -0.000436245,   -0.487908065,\
    -0.195724189,    0.915696681,   -0.350990891,\
    -0.000373655,    0.000461895,  -71.707321167,\
     2.374641418,   87.220207214,  130.913391113,\
    53.197921753,   90.173835754,  -20.000000000 )

#lighting----------------------------------------
#you can move the light source around to create shadows, etc
set light_count, 1
set light, (10,1,1)

#------------------ make figures ---------- 
#ray 900,700
#save tet_view_4.png


